@@ -8,6 +8,8 @@ MUST_BE_UNIQUE = "_must_be_unique"
 IGNORE_NONE_VALUES = "_ignore_none"
 SERIALIZATION_MAPPER = "_serialization_mapper"
 DESERIALIZATION_MAPPER = "_deserialization_mapper"
+ENABLE_UNDEFINED = "_enable_undefined_value"
+
 SPECIAL_ATTRIBUTES = {
     REQUIRED_FIELDS,
     ADDITIONAL_PROPERTIES,
@@ -17,5 +19,6 @@ SPECIAL_ATTRIBUTES = {
     SERIALIZATION_MAPPER,
     DESERIALIZATION_MAPPER,
     IGNORE_NONE_VALUES,
+    ENABLE_UNDEFINED
 }
 MAX_NUMBER_OF_INSTANCES_TO_VERIFY_UNIQUENESS = 100000
